Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(713)

Unified Diff: Source/core/html/parser/HTMLScriptRunner.h

Issue 15856002: First step of HTMLImports (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Fixed Mac build Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/html/parser/HTMLDocumentParser.cpp ('k') | Source/core/html/parser/HTMLScriptRunner.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/html/parser/HTMLScriptRunner.h
diff --git a/Source/core/html/parser/HTMLScriptRunner.h b/Source/core/html/parser/HTMLScriptRunner.h
index 0e52a700f2590e8b7111de0fa6c244c143f727d3..efa3fffa04c4a9bcdeb0a75109f85bf5e9242bf5 100644
--- a/Source/core/html/parser/HTMLScriptRunner.h
+++ b/Source/core/html/parser/HTMLScriptRunner.h
@@ -56,8 +56,8 @@ public:
void execute(PassRefPtr<Element> scriptToProcess, const TextPosition& scriptStartPosition);
void executeScriptsWaitingForLoad(CachedResource*);
- bool hasScriptsWaitingForStylesheets() const { return m_hasScriptsWaitingForStylesheets; }
- void executeScriptsWaitingForStylesheets();
+ bool hasScriptsWaitingForResources() const { return m_hasScriptsWaitingForResources; }
+ void executeScriptsWaitingForResources();
bool executeScriptsWaitingForParsing();
bool hasParserBlockingScript() const;
@@ -93,8 +93,8 @@ private:
// We only want stylesheet loads to trigger script execution if script
// execution is currently stopped due to stylesheet loads, otherwise we'd
// cause nested script execution when parsing <style> tags since </style>
- // tags can cause Document to call executeScriptsWaitingForStylesheets.
- bool m_hasScriptsWaitingForStylesheets;
+ // tags can cause Document to call executeScriptsWaitingForResources.
+ bool m_hasScriptsWaitingForResources;
};
}
« no previous file with comments | « Source/core/html/parser/HTMLDocumentParser.cpp ('k') | Source/core/html/parser/HTMLScriptRunner.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698